==> haskell-store-core-0.4.4.7-103.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-4ximLRZZ9bR3ae409s7f77
key:                  store-core-0.4.4.7-4ximLRZZ9bR3ae409s7f77
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  26c366bd3653fc851a996afb8eba54db
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-4ximLRZZ9bR3ae409s7f77
depends:
    base-4.18.2.1 bytestring-0.11.5.3 ghc-prim-0.10.0
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-core-0.4.4.7-104-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-EeVgJIwXwVVB92IvRZxWgj
key:                  store-core-0.4.4.7-EeVgJIwXwVVB92IvRZxWgj
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  cf98ce2d63e109e6c41c5648d7406357
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-EeVgJIwXwVVB92IvRZxWgj
depends:
    base-4.18.2.1 bytestring-0.11.5.3 ghc-prim-0.10.0
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
